@@ -195,7 +195,7 @@ def createParsers(app_name = 'backintime'):
     #define main argument parser
     parser = argparse.ArgumentParser(prog = app_name,
                                      parents = [commonArgsParser],
-                                     description = '%(app)s - a simple backup tool for Linux.'
+                                     description = '%(app)s - a simple backup tool for GNU/Linux.'
                                                    % {'app': config.Config.APP_NAME},
                                      epilog = "For backwards compatibility commands can also be used with trailing '--'. "
                                               "All listed arguments will work with all commands. Some commands have extra arguments. "
@@ -375,7 +375,7 @@ def createParsers(app_name = 'backintime'):
                                                  type = str,
                                                  action = 'store',
                                                  nargs = '?',
-                                                 help = 'Restore file or folder WHAT.')
+                                                 help = 'Restore file or directory WHAT.')
 
     restoreCP.add_argument                      ('WHERE',
                                                  type = str,
@@ -509,8 +509,10 @@ def startApp(app_name='backintime'):
     args = argParse(None)
 
     # Name, Version, As Root, OS
+    msg = ''
     for key, val in collect_minimal_diagnostics().items():
-        logger.debug(f'{key}: {val}')
+        msg = f'{msg}; {key}: {val}'
+    logger.debug(msg[2:])
 
     # Add source path to $PATH environ if running from source
     if tools.runningFromSource():
@@ -610,8 +612,8 @@ def argParse(args):
         for key
         in filter(lambda key: args_dict[key] is not None, args_dict)
     }
-    logger.debug(f'Used argument(s): {used_args}')
-    logger.debug(f'Unknown argument(s): {unknownArgs}')
+
+    logger.debug(f'Argument(s) used: {used_args}')
 
     # Report unknown arguments but not if we run aliasParser next because we
     # will parse again in there.
@@ -693,26 +695,33 @@ def getConfig(args, check = True):
                         2 if ``check`` is ``True`` and config is not configured
     """
     cfg = config.Config(config_path = args.config, data_path = args.share_path)
-    logger.debug('config file: %s' % cfg._LOCAL_CONFIG_PATH)
-    logger.debug('share path: %s' % cfg._LOCAL_DATA_FOLDER)
-    logger.debug('profiles: %s' % ', '.join('%s=%s' % (x, cfg.profileName(x))
-                                                        for x in cfg.profiles()))
+    logger.debug('config file: "{}"; share path: "{}"; profiles: "{}"'.format(
+        cfg._LOCAL_CONFIG_PATH,
+        cfg._LOCAL_DATA_FOLDER,
+        ', '.join(f'{profile_id}={cfg.profileName(profile_id)}'
+                  for profile_id in cfg.profiles())
+    ))
 
     if 'profile_id' in args and args.profile_id:
         if not cfg.setCurrentProfile(args.profile_id):
             logger.error('Profile-ID not found: %s' % args.profile_id)
             sys.exit(RETURN_ERR)
+
     if 'profile' in args and args.profile:
         if not cfg.setCurrentProfileByName(args.profile):
             logger.error('Profile not found: %s' % args.profile)
             sys.exit(RETURN_ERR)
+
     if check and not cfg.isConfigured():
         logger.error('%(app)s is not configured!' %{'app': cfg.APP_NAME})
         sys.exit(RETURN_NO_CFG)
+
     if 'checksum' in args:
         cfg.forceUseChecksum = args.checksum
+
     return cfg
 
+
 def setQuiet(args):
     """
     Redirect :py:data:`sys.stdout` to ``/dev/null`` if ``--quiet`` was set on
