@@ -1,21 +1,15 @@
-# Back In Time
-# Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey,
-# Germar Reitze
+# SPDX-FileCopyrightText: © 2008-2022 Oprea Dan
+# SPDX-FileCopyrightText: © 2008-2022 Bart de Koning
+# SPDX-FileCopyrightText: © 2008-2022 Richard Bailey
+# SPDX-FileCopyrightText: © 2008-2022 Germar Reitze
+# SPDX-FileCopyrightText: © 2024 Christian Buhtz <c.buhtz@posteo.jp>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""Configuration logic.
+# This file is part of the program "Back In Time" which is released under GNU
+# General Public License v2 (GPLv2). See LICENSES directory or go to
+# <https://spdx.org/licenses/GPL-2.0-or-later.html>.
+"""Configuration handling and logic.
 
 This module and its `Config` class contain the application logic handling the
 configuration of Back In Time. The handling of the configuration file itself
@@ -32,7 +26,6 @@ import sys
 import datetime
 import socket
 import random
-import textwrap
 import getpass
 import shlex
 # Workaround: Mostly relevant on TravisCI but not exclusively.
@@ -57,13 +50,13 @@ from exceptions import PermissionDeniedByPolicy, \
                        InvalidChar, \
                        InvalidCmd, \
                        LimitExceeded
-import version
 
 
 class Config(configfile.ConfigFileWithProfiles):
     APP_NAME = 'Back In Time'
     COPYRIGHT = 'Copyright (C) 2008-2024 Oprea Dan, Bart de Koning, ' \
-                'Richard Bailey, Germar Reitze, Christian Buhtz, Michael Büker, Jürgen Altfeld et al.'
+                'Richard Bailey, Germar Reitze, Christian Buhtz, ' \
+                'Michael Büker, Jürgen Altfeld et al.'
 
     CONFIG_VERSION = 6
     """Latest or highest possible version of Back in Time's config file."""
@@ -178,16 +171,6 @@ class Config(configfile.ConfigFileWithProfiles):
             self._LOCAL_CONFIG_PATH = os.path.abspath(config_path)
             self._LOCAL_CONFIG_FOLDER = os.path.dirname(self._LOCAL_CONFIG_PATH)
 
-        # (buhtz) Introduced in 2009 via commit 5b26575be4.
-        # Ready to remove after 15 years.
-        # old_path = os.path.join(self._LOCAL_CONFIG_FOLDER, 'config2')
-
-        # if os.path.exists(old_path):
-        #     if os.path.exists(self._LOCAL_CONFIG_PATH):
-        #         os.remove(old_path)
-        #     else:
-        #         os.rename(old_path, self._LOCAL_CONFIG_PATH)
-
         # Load global config file
         self.load(self._GLOBAL_CONFIG_PATH)
 
@@ -200,38 +183,15 @@ class Config(configfile.ConfigFileWithProfiles):
             = self.intValue('config.version', self.CONFIG_VERSION)
 
         if currentConfigVersion < self.CONFIG_VERSION:
-            # config.version value wasn't stored since BiT version 0.9.99.22
-            # until version 1.2.0 because of a bug. So we can't really tell
-            # which version the config is. But most likely it is version > 4
-            if currentConfigVersion < 4:
-                #update from BackInTime version < 1.0 is deprecated
-                logger.error("config.version is < 4. This config was made with "\
-                             "BackInTime version < 1.0. This version ({}) "     \
-                             "doesn't support upgrading config from version "   \
-                             "< 1.0 anymore. Please use BackInTime version "    \
-                             "<= 1.1.12 to upgrade the config to a more recent "\
-                             "version.".format(version.__version__))
-                #TODO: add popup warning
-                sys.exit(2)
-
             if currentConfigVersion < 5:
-                logger.info("Update to config version 5: other snapshot locations", self)
-                profiles = self.profiles()
-                for profile_id in profiles:
-                    #change include
-                    old_values = self.includeV4(profile_id)
-                    values = []
-                    for value in old_values:
-                        values.append((value, 0))
-                    self.setInclude(values, profile_id)
-
-                    #change exclude
-                    old_values = self.excludeV4(profile_id)
-                    self.setExclude(old_values, profile_id)
-
-                    #remove keys
-                    self.removeProfileKey('snapshots.include_folders', profile_id)
-                    self.removeProfileKey('snapshots.exclude_patterns', profile_id)
+                logger.error(
+                    'The config file version is 4 or lower. This config was '
+                    'made with a version of Back In Time that is out dated. '
+                    'Because of that upgrading config to the current version '
+                    'is not possible. The latest Back In Time version '
+                    'supporting upgrade the config file was v1.5.2.',
+                    self)
+                sys.exit(2)
 
             if currentConfigVersion < 6:
                 logger.info('Update to config version 6', self)
@@ -269,6 +229,7 @@ class Config(configfile.ConfigFileWithProfiles):
                 # remove old gnome and kde keys
                 self.removeKeysStartsWith('gnome')
                 self.removeKeysStartsWith('kde')
+
             self.save()
 
         self.current_hash_id = 'local'
@@ -349,26 +310,27 @@ class Config(configfile.ConfigFileWithProfiles):
         for profile_id in profiles:
             profile_name = self.profileName(profile_id)
             snapshots_path = self.snapshotsPath(profile_id)
-            logger.debug('Check profile %s' %profile_name, self)
+            logger.debug(f'Check profile {profile_name}', self)
 
-            #check snapshots path
+            # check snapshots path
             if not snapshots_path:
                 self.notifyError(
                     '{}\n{}'.format(
                         _('Profile: "{name}"').format(name=profile_name),
-                        _('Snapshots folder is not valid!')
+                        _('Snapshots directory is not valid.')
                     )
                 )
                 return False
 
-            #check include
+            # check include
             include_list = self.include(profile_id)
 
             if not include_list:
                 self.notifyError(
                     '{}\n{}'.format(
                         _('Profile: "{name}"').format(name=profile_name),
-                        _('You must select at least one folder to back up!')
+                        _('At least one directory must be selected '
+                          'for backup.')
                     )
                 )
 
@@ -385,7 +347,8 @@ class Config(configfile.ConfigFileWithProfiles):
                     self.notifyError(
                         '{}\n{}'.format(
                             _('Profile: "{name}"').format(name=profile_name),
-                            _("Backup folder cannot be included.")
+                            _('The directory cannot be included in the '
+                              'backup.')
                         )
                     )
 
@@ -397,31 +360,45 @@ class Config(configfile.ConfigFileWithProfiles):
                             '{}\n{}'.format(
                                 _('Profile: "{name}"').format(
                                     name=profile_name),
-                                _("Backup sub-folder cannot be included.")
+                                _('The sub-directories cannot be included in '
+                                  'the backup.')
                             )
                         )
 
                         return False
         return True
 
-    def pid(self):
-        return str(os.getpid())
-
     def host(self):
         return socket.gethostname()
 
-    def snapshotsPath(self, profile_id = None, mode = None, tmp_mount = False):
+    def get_snapshots_mountpoint(self, profile_id=None, mode=None, tmp_mount=False):
+        """Return the profiles snapshot path in form of a mount point."""
+        if profile_id is None:
+            profile_id = self.currentProfile()
+
         if mode is None:
             mode = self.snapshotsMode(profile_id)
-        if self.SNAPSHOT_MODES[mode][0] == None:
-            #no mount needed
-            #?Where to save snapshots in mode 'local'. This path must contain a
-            #?folderstructure like 'backintime/<HOST>/<USER>/<PROFILE_ID>';absolute path
-            return self.profileStrValue('snapshots.path', '', profile_id)
-        else:
-            #mode need to be mounted; return mountpoint
-            symlink = self.snapshotsSymlink(profile_id = profile_id, tmp_mount = tmp_mount)
-            return os.path.join(self._LOCAL_MOUNT_ROOT, symlink)
+
+        if mode == 'local':
+            return self.get_snapshots_path(profile_id)
+
+        # else: ssh/local_encfs/ssh_encfs
+
+        symlink = f'{profile_id}_{os.getpid()}'
+        if tmp_mount:
+            symlink = f'tmp_{symlink}'
+
+        return os.path.join(self._LOCAL_MOUNT_ROOT, symlink)
+
+    def snapshotsPath(self, profile_id=None, mode=None, tmp_mount=False):
+        """Return the snapshot path (backup destination) as a mount point.
+
+        That method is a surrogate for `self.get_snapshots_mountpoint()`.
+        """
+        return self.get_snapshots_mountpoint(
+            profile_id=profile_id,
+            mode=mode,
+            tmp_mount=tmp_mount)
 
     def snapshotsFullPath(self, profile_id = None):
         """
@@ -430,94 +407,16 @@ class Config(configfile.ConfigFileWithProfiles):
         host, user, profile = self.hostUserProfile(profile_id)
         return os.path.join(self.snapshotsPath(profile_id), 'backintime', host, user, profile)
 
-    def setSnapshotsPath(self, value, profile_id = None, mode = None):
-        """
-        Sets the snapshot path to value, initializes, and checks it
-        """
-        if not value:
-            return False
+    def get_snapshots_path(self, profile_id):
+        """Return the value of the snapshot path (backup destination) field."""
+        return self.profileStrValue('snapshots.path', '', profile_id)
 
-        if profile_id == None:
+    def set_snapshots_path(self, value, profile_id=None):
+        """Sets the snapshot path to value."""
+        if profile_id is None:
             profile_id = self.currentProfile()
 
-        if mode is None:
-            mode = self.snapshotsMode(profile_id)
-
-        if not os.path.isdir(value):
-            self.notifyError(_('Invalid option. {path} is not a folder.').format(path=value))
-            return False
-
-        # Initialize the snapshots folder
-        logger.debug("Check snapshot folder: %s" % value, self)
-
-        host, user, profile = self.hostUserProfile(profile_id)
-
-        if not all((host, user, profile)):
-            self.notifyError(_('Host/User/Profile-ID must not be empty.'))
-            return False
-
-        full_path = os.path.join(value, 'backintime', host, user, profile)
-        if not os.path.isdir(full_path):
-            logger.debug("Create folder: %s" % full_path, self)
-            tools.makeDirs(full_path)
-
-            if not os.path.isdir(full_path):
-                self.notifyError(_(
-                    "Can't write to: {path}\nAre you sure you have "
-                    "write access?").format(path=value))
-                return False
-
-            for p in (os.path.join(value, 'backintime'),
-                      os.path.join(value, 'backintime', host)):
-                try:
-                    os.chmod(p, 0o777)
-                except PermissionError as e:
-                    msg = "Failed to set permissions world-writable for '{}': {}"
-                    logger.warning(msg.format(p, str(e)), self)
-
-        # Test filesystem
-        fs = tools.filesystem(full_path)
-
-        if fs == 'vfat':
-            self.notifyError(_(
-                "Destination filesystem for {path} is formatted with FAT "
-                "which doesn't support hard-links. "
-                "Please use a native Linux filesystem.")
-                .format(path=value))
-
-            return False
-
-        elif fs == 'cifs' and not self.copyLinks():
-            self.notifyError(_(
-                'Destination filesystem for {path} is an SMB-mounted share. '
-                'Please make sure the remote SMB server supports symlinks or '
-                'activate {copyLinks} in {expertOptions}.')
-                .format(path=value,
-                        copyLinks=_('Copy links (dereference symbolic links)'),
-                        expertOptions=_('Expert Options')))
-
-        elif fs == 'fuse.sshfs' and mode not in ('ssh', 'ssh_encfs'):
-            self.notifyError(_(
-                "Destination filesystem for {path} is an sshfs-mounted share."
-                " Sshfs doesn't support hard-links. "
-                "Please use mode 'SSH' instead.")
-                .format(path=value))
-
-            return False
-
-        #Test write access for the folder
-        check_path = os.path.join(full_path, 'check')
-        tools.makeDirs(check_path)
-        if not os.path.isdir(check_path):
-            self.notifyError(_(
-                "Can't write to: {path}\nAre you sure you have "
-                "write access?").format(path=full_path))
-            return False
-
-        os.rmdir(check_path)
-        if self.SNAPSHOT_MODES[mode][0] is None:
-            self.setProfileStrValue('snapshots.path', value, profile_id)
-        return True
+        self.setProfileStrValue('snapshots.path', value, profile_id)
 
     def snapshotsMode(self, profile_id=None):
         #? Use mode (or backend) for this snapshot. Look at 'man backintime'
@@ -527,14 +426,6 @@ class Config(configfile.ConfigFileWithProfiles):
     def setSnapshotsMode(self, value, profile_id = None):
         self.setProfileStrValue('snapshots.mode', value, profile_id)
 
-    def snapshotsSymlink(self, profile_id = None, tmp_mount = False):
-        if profile_id is None:
-            profile_id = self.current_profile_id
-        symlink = '%s_%s' % (profile_id, self.pid())
-        if tmp_mount:
-            symlink = 'tmp_%s' % symlink
-        return symlink
-
     def setCurrentHashId(self, hash_id):
         self.current_hash_id = hash_id
 
@@ -670,17 +561,14 @@ class Config(configfile.ConfigFileWithProfiles):
 
     def sshProxyPort(self, profile_id=None):
         #?Proxy host port used to connect to remote host.;0-65535
-        return self.profileIntValue(
-            'snapshots.ssh.proxy_host_port', '22', profile_id)
+        return self.profileIntValue('snapshots.ssh.proxy_host_port', '22', profile_id)
 
     def setSshProxyPort(self, value, profile_id = None):
-        self.setProfileIntValue(
-            'snapshots.ssh.proxy_host_port', value, profile_id)
+        self.setProfileIntValue('snapshots.ssh.proxy_host_port', value, profile_id)
 
     def sshProxyUser(self, profile_id=None):
-        #?Remote SSH user;;local users name
-        return self.profileStrValue(
-            'snapshots.ssh.proxy_user', getpass.getuser(), profile_id)
+        #?Remote SSH user;;the local users name
+        return self.profileStrValue('snapshots.ssh.proxy_user', getpass.getuser(), profile_id)
 
     def setSshProxyUser(self, value, profile_id=None):
         self.setProfileStrValue('snapshots.ssh.proxy_user', value, profile_id)
@@ -688,7 +576,7 @@ class Config(configfile.ConfigFileWithProfiles):
     def sshMaxArgLength(self, profile_id = None):
         #?Maximum command length of commands run on remote host. This can be tested
         #?for all ssh profiles in the configuration
-        #?with 'python3 /usr/share/backintime/common/sshMaxArg.py [initial_ssh_cmd_length]'.\n
+        #?with 'python3 /usr/share/backintime/common/ssh_max_arg.py LENGTH'.\n
         #?0 = unlimited;0, >700
         value = self.profileIntValue('snapshots.ssh.max_arg_length', 0, profile_id)
         if value and value < 700:
@@ -842,11 +730,10 @@ class Config(configfile.ConfigFileWithProfiles):
     def passwordUseCache(self, profile_id = None, mode = None):
         if mode is None:
             mode = self.snapshotsMode(profile_id)
-        default = not tools.checkHomeEncrypt()
         #?Cache password in RAM so it can be read by cronjobs.
         #?Security issue: root might be able to read that password, too.
-        #?<MODE> must be the same as \fIprofile<N>.snapshots.mode\fR;;true if home is not encrypted
-        return self.profileBoolValue('snapshots.%s.password.use_cache' % mode, default, profile_id)
+        #?<MODE> must be the same as \fIprofile<N>.snapshots.mode\fR;;true
+        return self.profileBoolValue('snapshots.%s.password.use_cache' % mode, True, profile_id)
 
     def setPasswordUseCache(self, value, profile_id = None, mode = None):
         if mode is None:
@@ -929,41 +816,14 @@ class Config(configfile.ConfigFileWithProfiles):
         self.setProfileStrValue('snapshots.path.user', user, profile_id)
         self.setProfileStrValue('snapshots.path.profile', profile, profile_id)
 
-    def includeV4(self, profile_id = None):
-        #?!ignore this in manpage
-        value = self.profileStrValue('snapshots.include_folders', '', profile_id)
-        if not value:
-            return []
-
-        paths = []
-
-        for item in value.split(':'):
-            fields = item.split('|')
-
-            path = os.path.expanduser(fields[0])
-            path = os.path.abspath(path)
-            paths.append(path)
-
-        return paths
-
-    def include(self, profile_id = None):
+    def include(self, profile_id=None):
         #?Include this file or folder. <I> must be a counter starting with 1;absolute path::
         #?Specify if \fIprofile<N>.snapshots.include.<I>.value\fR is a folder (0) or a file (1).;0|1;0
-        return self.profileListValue('snapshots.include', ('str:value', 'int:type'), [], profile_id)
+        return self.profileListValue(key='snapshots.include', type_key=('str:value', 'int:type'), default=[], profile_id=profile_id)
 
     def setInclude(self, values, profile_id = None):
         self.setProfileListValue('snapshots.include', ('str:value', 'int:type'), values, profile_id)
 
-    def excludeV4(self, profile_id = None):
-        """
-        Gets the exclude patterns: conf version 4
-        """
-        #?!ignore this in manpage
-        value = self.profileStrValue('snapshots.exclude_patterns', '.gvfs:.cache*:[Cc]ache*:.thumbnails*:[Tt]rash*:*.backup*:*~', profile_id)
-        if not value:
-            return []
-        return value.split(':')
-
     def exclude(self, profile_id = None):
         """
         Gets the exclude patterns
@@ -1352,19 +1212,7 @@ class Config(configfile.ConfigFileWithProfiles):
 
     def rsyncOptions(self, profile_id = None):
         #?rsync options. Options must be quoted e.g. \-\-exclude-from="/path/to/my exclude file"
-        val = self.profileStrValue('snapshots.rsync_options.value', '', profile_id)
-
-        if '--old-args' in val:
-            logger.warning(
-                'Found rsync flag "--old-args". That flag will be removed '
-                'from the options because it conflicts with '
-                'the flag "-s" (also known as "--secluded-args" or '
-                '"--protected-args") which is used by Back In Time to force '
-                'the "new form of argument protection" in rsync.'
-            )
-            val = val.replace('--old-args', '')
-
-        return val
+        return self.profileStrValue('snapshots.rsync_options.value', '', profile_id)
 
     def setRsyncOptions(self, enabled, value, profile_id = None):
         self.setProfileBoolValue('snapshots.rsync_options.enabled', enabled, profile_id)
@@ -1434,13 +1282,6 @@ class Config(configfile.ConfigFileWithProfiles):
     def setTakeSnapshotRegardlessOfChanges(self, value, profile_id = None):
         return self.setProfileBoolValue('snapshots.take_snapshot_regardless_of_changes', value, profile_id)
 
-    def userCallbackNoLogging(self, profile_id = None):
-        #?Do not catch std{out|err} from user-callback script.
-        #?The script will only write to current TTY.
-        #?Default is to catch std{out|err} and write it to
-        #?syslog and TTY again.
-        return self.profileBoolValue('user_callback.no_logging', False, profile_id)
-
     def globalFlock(self):
         #?Prevent multiple snapshots (from different profiles or users) to be run at the same time
         return self.boolValue('global.use_flock', False)
@@ -1542,15 +1383,25 @@ class Config(configfile.ConfigFileWithProfiles):
                 path = path[: -1]
         return path
 
-    def isConfigured(self, profile_id = None):
-        """
-        Checks if the program is configured
-        """
-        return bool(self.snapshotsPath(profile_id) and self.include(profile_id))
+    def isConfigured(self, profile_id=None):
+        """Checks if the program is configured.
 
-    def canBackup(self, profile_id = None):
+        It is assumed as configured if a snapshot path (backup destination) is
+        and include files/directories (backup source) are given.
         """
-        Checks if snapshots_path exists
+        path = self.snapshotsPath(profile_id)
+        includes = self.include(profile_id)
+
+        if bool(path and includes):
+            return True
+        else:
+            logger.debug(f'Profile ({profile_id=}) is not configured because '
+                         f'snapshot path is "{bool(path)}" and/or includes '
+                         f'are "{bool(includes)}".', self)
+            return False
+
+    def canBackup(self, profile_id=None):
+        """Checks if snapshots_path exists.
         """
         if not self.isConfigured(profile_id):
             return False
@@ -1558,11 +1409,11 @@ class Config(configfile.ConfigFileWithProfiles):
         path = self.snapshotsFullPath(profile_id)
 
         if not os.path.exists(path):
+            logger.warning(f'Snapshot path does not exists: {path}', self)
             return False
 
         if not os.path.isdir(path):
-            # path exists, but is no dir: something's very wrong.
-            logger.error("%s is not a directory"%path, self)
+            logger.warning(f'Snapshot path is not a directory: {path}', self)
             return False
 
         return True
@@ -1580,37 +1431,11 @@ class Config(configfile.ConfigFileWithProfiles):
         if not last_time:
             return True
 
-        value = self.scheduleRepeatedPeriod(profile_id)
-        unit = self.scheduleRepeatedUnit(profile_id)
-
-        return self.olderThan(last_time, value, unit)
-
-    def olderThan(self, time, value, unit):
-        """
-        return True if time is older than months, weeks, days or hours
-        """
-        assert isinstance(time, datetime.datetime), 'time is not datetime.datetime type: %s' % time
-
-        now = datetime.datetime.now()
-
-        if unit <= self.HOUR:
-            return time < now - datetime.timedelta(hours = value)
-        elif unit <= self.DAY:
-            return time.date() <= now.date() - datetime.timedelta(days = value)
-        elif unit <= self.WEEK:
-            return time.date() < now.date() \
-                                 - datetime.timedelta(days = now.date().weekday()) \
-                                 - datetime.timedelta(weeks = value - 1)
-        elif unit <= self.MONTH:
-            firstDay = now.date() - datetime.timedelta(days = now.date().day + 1)
-            for i in range(value - 1):
-                if firstDay.month == 1:
-                    firstDay = firstDay.replace(month = 12, year = firstDay.year - 1)
-                else:
-                    firstDay = firstDay.replace(month = firstDay.month - 1)
-            return time.date() < firstDay
-        else:
-            return True
+        return tools.older_than(
+            dt=last_time,
+            value=self.scheduleRepeatedPeriod(profile_id),
+            unit=self.scheduleRepeatedUnit(profile_id)
+        )
 
     def setupCron(self):
         """Update the current users crontab file based on profile settings.
@@ -1667,7 +1492,7 @@ class Config(configfile.ConfigFileWithProfiles):
                 'available. Scheduled backup jobs will not run. '
                 'Cron might be installed but not enabled. Try the command '
                 '"systemctl enable cron" or consult the support channels of '
-                'your GNU Linux distribution.'))
+                'your GNU/Linux distribution.'))
 
         return True
 
@@ -1756,9 +1581,9 @@ class Config(configfile.ConfigFileWithProfiles):
                 dest_path = self.localEncfsPath(profile_id)
             else:
                 logger.error(
-                    'Schedule udev doesn\'t work with mode %s' % mode, self)
+                    f"Udev scheduling doesn't work with mode {mode}", self)
                 self.notifyError(_(
-                    "Schedule udev doesn't work with mode {mode}")
+                    "Udev schedule doesn't work with mode {mode}")
                     .format(mode=mode))
                 return False
             uuid = tools.uuidFromPath(dest_path)
@@ -1840,8 +1665,3 @@ class Config(configfile.ConfigFileWithProfiles):
             cmd = tools.which('nice') + ' -n19 ' + cmd
 
         return cmd
-
-
-if __name__ == '__main__':
-    config = Config()
-    print("snapshots path = %s" % config.snapshotsFullPath())
