@@ -27,6 +27,7 @@ from pathlib import Path
 from time import sleep
 import logger
 import tools
+import password
 import password_ipc
 from mount import MountControl
 from exceptions import MountException, NoPubKeyLogin, KnownHost
@@ -236,7 +237,7 @@ class SSH(MountControl):
 
         raise MountException(
             "{}\n\n{}".format(
-                _("Can't mount {sshfs}").format(sshfs=" ".join(sshfs)),
+                _('Unable to mount {sshfs}').format(sshfs=" ".join(sshfs)),
                 err
             )
         )
@@ -252,14 +253,20 @@ class SSH(MountControl):
         to run a full check with all tests.
 
         Args:
-            first_run (bool):           run a full test with all checks
+            first_run (bool): Run a full test with all checks.
 
         Raises:
-            exceptions.MountException:  if one test failed an we can not mount
-                                        the remote path
+            exceptions.MountException: If one test failed an we can not mount
+                the remote path.
         """
 
+        # Most of the called methods will raise an exception if something is
+        # wrong.
+
+        # try to open SSH socket
         self.checkPingHost()
+
+        # sshfs (self.mountproc) installed?
         self.checkFuse()
 
         if first_run:
@@ -298,7 +305,7 @@ class SSH(MountControl):
 
         if not sshAgent:
             raise MountException(
-                _('ssh-agent not found. Please make sure it is installed.'))
+                _('ssh-agent not found. Please ensure it is installed.'))
 
         if isinstance(sshAgent, str):
             sshAgent = [sshAgent, ]
@@ -337,12 +344,11 @@ class SSH(MountControl):
         by ``backintime-askpass``.
 
         Args:
-            force (bool):               force to unlock the key by removing it
-                                        first and add it again to make sure,
-                                        the given values are correct
+            force (bool): Force to unlock the key by removing it first and add
+                it again to make sure, the given values are correct.
 
         Raises:
-            exceptions.MountException:  if unlock failed
+            exceptions.MountException: If unlock failed.
         """
 
         self.startSshAgent()
@@ -381,7 +387,7 @@ class SSH(MountControl):
             password_available = any([
                 self.config.passwordSave(self.profile_id),
                 self.config.passwordUseCache(self.profile_id),
-                not self.password is None
+                self.password is not None
             ])
 
             logger.debug('Password available: %s' % password_available, self)
@@ -412,6 +418,33 @@ class SSH(MountControl):
                     env['ASKPASS_TEMP'] = thread.temp_file
                     thread.start()
 
+                # We need to validate the ssh key password which
+                # `backintime-askpass` will provide before calling
+                # ssh-add below. See Issue #1852.
+
+                # Validate cached SSH key password:
+                proc = subprocess.run(
+                        ['ssh-keygen', '-y', '-f', self.private_key_file],
+                        capture_output=True,
+                        # Ensure ssh-keygen uses backintime-askpass
+                        env=env | {'SSH_ASKPASS_REQUIRE': 'prefer'}
+                )
+
+                # if backintime-askpass supplied an invalid cached password
+                if proc.returncode > 0:
+                    pw = password.Password()
+
+                    # pw_id = 1 corresponds to the SSH password
+                    # (as opposed to the encryption password)
+                    # See qt/settingsdialog.py:SettingsDialog.updateProfile()
+                    pw.password(
+                        None,
+                        self.profile_id,
+                        self.mode,
+                        pw_id=1,
+                        refresh=True,
+                    )
+
                 proc = subprocess.Popen(['ssh-add', self.private_key_file],
                                         stdin=subprocess.PIPE,
                                         stdout=subprocess.PIPE,
@@ -440,6 +473,7 @@ class SSH(MountControl):
                 logger.debug(
                     'Was not able to unlock private key %s' %
                     self.private_key_file, self)
+
                 raise MountException(
                     _('Could not unlock ssh private key. Wrong password '
                       'or password not available for cron.'))
@@ -449,12 +483,11 @@ class SSH(MountControl):
                          % self.private_key_file, self)
 
     def checkLogin(self):
-        """
-        Try to login to remote host with public/private-key-method
+        """Try to login to remote host with public/private-key-method
         (passwordless).
 
         Raises:
-            exceptions.NoPubKeyLogin:  if login failed
+            exceptions.NoPubKeyLogin: If login failed.
         """
 
         logger.debug('Check login', self)
@@ -492,12 +525,11 @@ class SSH(MountControl):
                 + '\n\n' + err)
 
     def checkCipher(self):
-        """
-        Try to login to remote host with the chosen cipher. This should make
+        """Try to login to remote host with the chosen cipher. This should make
         sure both `localhost` and the remote host support the chosen cipher.
 
         Raises:
-            exceptions.MountException:  if login with the cipher failed
+            exceptions.MountException: If login with the cipher failed.
         """
 
         if not self.cipher == 'default':
@@ -535,6 +567,7 @@ class SSH(MountControl):
                 msg = _('Cipher {cipher} failed for {host}.').format(
                     cipher=self.config.SSH_CIPHERS[self.cipher],
                     host=self.host)
+
                 raise MountException(f'{msg}:\n{err}')
 
     def benchmarkCipher(self, size=40):
@@ -594,12 +627,11 @@ class SSH(MountControl):
         os.remove(temp)
 
     def checkKnownHosts(self):
-        """
-        Check if the remote host is in current users ``known_hosts`` file.
+        """Check if the remote host is in current users ``known_hosts`` file.
 
         Raises:
-            exceptions.KnownHost:   if the remote host wasn't found
-                                    in ``known_hosts`` file
+            exceptions.KnownHost: If the remote host wasn't found
+                in ``known_hosts`` file.
         """
 
         logger.debug('Check known hosts file', self)
@@ -634,7 +666,7 @@ class SSH(MountControl):
                                         doesn't have correct permissions.
         """
 
-        logger.debug('Check remote folder', self)
+        logger.debug('Check remote directory', self)
 
         cmd = 'd=0;'
         # path doesn't exist. set d=1 to indicate
@@ -699,21 +731,20 @@ class SSH(MountControl):
         else:
 
             # returncode is 0
-            logger.info('Create remote folder %s' % self.path, self)
+            logger.info(f'Create remote path {self.path}', self)
 
     def checkPingHost(self):
         """
         Check if the remote host is online. Other than methods name may let
-        suppose
-        this does not use Ping (``ICMP``) but try to open a connection to
-        the configured port on the remote host. In this way it will even work
-        on remote hosts which have ``ICMP`` disabled.
+        suppose this does not use Ping (``ICMP``) but try to open a connection
+        to the configured port on the remote host. In this way it will even
+        work on remote hosts which have ``ICMP`` disabled.
 
         If connection failed it will retry five times before failing.
 
         Raises:
-            exceptions.MountException:  if connection failed most probably
-                                        because remote host is offline
+            exceptions.MountException: If connection failed most probably
+                because remote host is offline.
         """
 
         if not self.config.sshCheckPingHost(self.profile_id):
@@ -763,19 +794,18 @@ class SSH(MountControl):
 
     def checkRemoteCommands(self, retry=False):
         """
-        Try out all relevant commands used by `Back In Time` on the remote
-        host to make sure snapshots will be successful with the remote host.
-        This will also check that hard-links are supported on the remote host.
-        This check can be disabled
-        with :py:func:`config.Config.sshCheckCommands`
+        Try out all relevant commands used by Back In Time on the remote host
+        to make sure snapshots will be successful with the remote host. This
+        will also check that hard-links are supported on the remote host. This
+        check can be disabled with :py:func:`config.Config.sshCheckCommands`.
 
         Args:
-            retry (bool):               retry to run the commands if it failed
-                                        because the command string was to long
+            retry (bool): Retry to run the commands if it failed because the
+                command string was to long.
+
         Raises:
-            exceptions.MountException:  if a command is not supported on
-                                        remote host or if hard-links are not
-                                        supported
+            exceptions.MountException: If a command is not supported on remote
+                host or if hard-links are not supported.
         """
 
         if not self.config.sshCheckCommands():
@@ -795,9 +825,9 @@ class SSH(MountControl):
                 'We will test max arg length now and retry.',
                 self)
 
-            import sshMaxArg
-            max_arg_size = sshMaxArg.probe_max_ssh_command_size(self.config)
-            sshMaxArg.report_result(self.host, max_arg_size)
+            import ssh_max_arg
+            max_arg_size = ssh_max_arg.probe_max_ssh_command_size(self.config)
+            ssh_max_arg.report_result(self.host, max_arg_size)
 
             self.config.setSshMaxArgLength(max_arg_size, self.profile_id)
 
@@ -840,7 +870,7 @@ class SSH(MountControl):
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE,
                                         universal_newlines=True)
-                out, err = proc.communicate()
+                err = proc.communicate()[1]
 
                 if err or proc.returncode:
                     logger.debug(f'rsync command returned error: {err}', self)
@@ -1057,7 +1087,7 @@ def sshKeyGen(keyfile):
                             stderr=subprocess.PIPE,
                             universal_newlines=True)
 
-    out, err = proc.communicate()
+    err = proc.communicate()[1]
 
     if proc.returncode:
         logger.error('Failed to create a new ssh-key: {}'.format(err))
@@ -1178,7 +1208,7 @@ def sshCopyId(
                                                    # backintime-askpass
                             universal_newlines=True)
 
-    out, err = proc.communicate()
+    err = proc.communicate()[1]
 
     if proc.returncode:
         logger.error('Failed to copy ssh-key "{}" to "{}@{}": [{}] {}'
