@@ -35,7 +35,7 @@ SKIP_MESSAGE_SSH = 'Skip as this test requires a local ssh server, public ' \
                    'and private keys installed'
 
 @unittest.skipIf(not generic.LOCAL_SSH, SKIP_MESSAGE_SSH)
-class TestSSH(generic.SSHTestCase):
+class General(generic.SSHTestCase):
     def test_can_mount_ssh_rw(self):
         mnt = mount.Mount(cfg = self.cfg, tmp_mount = True)
         mnt.preMountCheck(mode = 'ssh', first_run = True, **self.mount_kwargs)
@@ -224,8 +224,8 @@ class TestSSH(generic.SSHTestCase):
         ssh = sshtools.SSH(cfg = self.cfg)
         self.assertRegex(ssh.randomId(size = 6), r'[A-Z0-9]{6}')
 
-class TestSshKey(generic.TestCaseCfg):
-    def test_sshKeyGen(self):
+class SshKey(generic.TestCaseCfg):
+    def test_generate(self):
         with TemporaryDirectory() as tmp:
             secKey = os.path.join(tmp, 'key')
             pubKey = secKey + '.pub'
@@ -237,9 +237,10 @@ class TestSshKey(generic.TestCaseCfg):
             # do not overwrite existing keys
             self.assertFalse(sshtools.sshKeyGen(secKey))
 
-    @unittest.skipIf(not tools.checkCommand('ssh-keygen'),
-                     "'ssh-keygen' not found.")
-    def test_sshKeyFingerprint(self):
+    @unittest.skipIf(not tools.checkCommand('ssh-keygen')
+                     and not generic.ON_TRAVIS,  # enforce test on TravisCI
+                     "'ssh-keygen' not found." )
+    def test_fingerprint(self):
         self.assertIsNone(
             sshtools.sshKeyFingerprint(os.path.abspath(__file__)))
 
@@ -259,7 +260,7 @@ class TestSshKey(generic.TestCaseCfg):
                 self.assertRegex(fingerprint, r'^[a-fA-F0-9:]+$')
 
     @unittest.skipIf(not generic.LOCAL_SSH, 'Skip as this test requires a local ssh server, public and private keys installed')
-    def test_sshHostKey(self):
+    def test_host_key(self):
         fingerprint, keyHash, keyType = sshtools.sshHostKey('localhost')
         self.assertIsInstance(fingerprint, str)
         self.assertIsInstance(keyHash, str)
@@ -275,15 +276,8 @@ class TestSshKey(generic.TestCaseCfg):
 
         hostKey = '/etc/ssh/ssh_host_{}_key.pub'.format(keyType.lower())
         self.assertExists(hostKey)
-        self.assertEqual(3, len(keyHash.split()))
-        try:
-            with open(hostKey, 'rt') as f:
-                pubKey = f.read().split()[1]
-            self.assertEqual(pubKey, keyHash.split()[2])
-        except (IOError, IndexError):
-            pass
 
-    def test_writeKnownHostFile(self):
+    def test_write_known_host_file(self):
         KEY = '|1|abcdefghijklmnopqrstuvwxyz= ecdsa-sha2-nistp256 AAAAABCDEFGHIJKLMNOPQRSTUVWXYZ='
         with TemporaryDirectory() as tmp:
             knownHosts = os.path.expanduser('~/.ssh/known_hosts')
@@ -303,13 +297,13 @@ class TestSshKey(generic.TestCaseCfg):
                     shutil.copyfile(knownHostsSic, knownHosts)
 
 @unittest.skipIf(not generic.LOCAL_SSH, SKIP_MESSAGE_SSH)
-class TestStartSshAgent(generic.SSHTestCase):
+class StartSshAgent(generic.SSHTestCase):
     # running this test requires that user has public / private key pair created and ssh server running
     SOCK = 'SSH_AUTH_SOCK'
     PID =  'SSH_AGENT_PID'
 
     def setUp(self):
-        super(TestStartSshAgent, self).setUp()
+        super().setUp()
         self.ssh = sshtools.SSH(cfg = self.cfg)
         self.currentSock = os.environ.pop(self.SOCK, '')
         self.currentPid  = os.environ.pop(self.PID, '')
@@ -318,14 +312,14 @@ class TestStartSshAgent(generic.SSHTestCase):
         os.environ[self.SOCK] = self.currentSock
         os.environ[self.PID]  = self.currentPid
 
-    def test_startSshAgent(self):
+    def test_just_start(self):
         self.ssh.startSshAgent()
         self.assertTrue(self.SOCK in os.environ)
         self.assertTrue(self.PID  in os.environ)
 
     @patch('tools.which')
     @patch('os.kill')
-    def test_startSshAgentEqualSign(self, mockKill, mockWhich):
+    def test_equal_sign(self, mockKill, mockWhich):
         mockWhich.return_value = ['echo', 'setenv SSH_AUTH_SOCK=/tmp/ssh-zWg8uTdgh1QJ/agent.9070;\n',
                                   'setenv SSH_AGENT_PID=9071;\n'
                                   'echo Agent pid 9071;']
@@ -335,7 +329,7 @@ class TestStartSshAgent(generic.SSHTestCase):
 
     @patch('tools.which')
     @patch('os.kill')
-    def test_startSshAgentSpace(self, mockKill, mockWhich):
+    def test_space(self, mockKill, mockWhich):
         mockWhich.return_value = ['echo', 'setenv SSH_AUTH_SOCK /tmp/ssh-zWg8uTdgh1QJ/agent.9070;\n',
                                   'setenv SSH_AGENT_PID 9071;\n'
                                   'echo Agent pid 9071;']
@@ -345,7 +339,7 @@ class TestStartSshAgent(generic.SSHTestCase):
 
     @patch('tools.which')
     @patch('os.kill')
-    def test_startSshAgentExport(self, mockKill, mockWhich):
+    def test_export(self, mockKill, mockWhich):
         mockWhich.return_value = ['echo', 'SSH_AUTH_SOCK=/tmp/ssh-zWg8uTdgh1QJ/agent.9070; export SSH_AUTH_SOCK;\n',
                                   'SSH_AGENT_PID=9071; export SSH_AGENT_PID;\n'
                                   'echo Agent pid 9071;']
@@ -354,13 +348,13 @@ class TestStartSshAgent(generic.SSHTestCase):
         self.assertTrue(self.PID  in os.environ)
 
     @patch('tools.which')
-    def test_startSshAgentError(self, mockWhich):
+    def test_error(self, mockWhich):
         mockWhich.return_value = '/bin/false'
         with self.assertRaises(MountException):
             self.ssh.startSshAgent()
 
     @patch('tools.which')
-    def test_startSshAgentMissing(self, mockWhich):
+    def test_missing(self, mockWhich):
         mockWhich.return_value = ''
         with self.assertRaises(MountException):
             self.ssh.startSshAgent()
