@@ -1,20 +1,14 @@
-# Back In Time
-# Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey,
-# Germar Reitze
+# SPDX-FileCopyrightText: © 2008-2022 Oprea Dan
+# SPDX-FileCopyrightText: © 2008-2022 Bart de Koning
+# SPDX-FileCopyrightText: © 2008-2022 Richard Bailey
+# SPDX-FileCopyrightText: © 2008-2022 Germar Reitze
+# SPDX-FileCopyrightText: © 2024 Christian Buhtz <c.buhtz@posteo.jp>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# This file is part of the program "Back In Time" which is released under GNU
+# General Public License v2 (GPLv2). See LICENSES directory or go to
+# <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 import os
 import sys
 
@@ -91,13 +85,17 @@ from PyQt6.QtCore import (Qt,
                           QSortFilterProxyModel,
                           QDir,
                           QUrl)
-import settingsdialog
+from manageprofiles import SettingsDialog
 import snapshotsdialog
 import logviewdialog
 from restoredialog import RestoreDialog
+from restoreconfigdialog import RestoreConfigDialog
 import languagedialog
 import messagebox
 from aboutdlg import AboutDlg
+import qttools
+from usermessagedialog import UserMessageDialog
+import version
 
 
 class MainWindow(QMainWindow):
@@ -186,7 +184,8 @@ class MainWindow(QMainWindow):
 
         # folder don't exist label
         self.lblFolderDontExists = QLabel(
-            _("This folder doesn't exist\nin the current selected snapshot."),
+            _("This directory doesn't exist\n"
+              "in the current selected snapshot."),
             self)
         qttools.setFontBold(self.lblFolderDontExists)
         self.lblFolderDontExists.setFrameShadow(QFrame.Shadow.Sunken)
@@ -346,12 +345,12 @@ class MainWindow(QMainWindow):
             message = f'{message}\n\n'
             message = message + _(
                 'Import an existing configuration (from a backup target '
-                'folder or another computer)?')
+                'directory or another computer)?')
             answer = messagebox.warningYesNo(self, message)
             if answer == QMessageBox.StandardButton.Yes:
-                settingsdialog.RestoreConfigDialog(self).exec()
+                RestoreConfigDialog(self).exec()
 
-            settingsdialog.SettingsDialog(self).exec()
+            SettingsDialog(self).exec()
 
         if not config.isConfigured():
             return
@@ -372,7 +371,7 @@ class MainWindow(QMainWindow):
             self.config.setCurrentHashId(hash_id)
 
         if not config.canBackup(profile_id):
-            msg = _("Can't find snapshots folder.") + '\n' \
+            msg = _("Can't find snapshots directory.") + '\n' \
                 + _('If it is on a removable drive please plug it in and then '
                     'press OK.')
             messagebox.critical(self, msg)
@@ -440,6 +439,13 @@ class MainWindow(QMainWindow):
                 dlg.exec()
                 self.config.setBoolValue('internal.msg_shown_encfs', True)
 
+        # Release Candidate
+        if version.is_release_candidate():
+            last_vers = self.config.strValue('internal.msg_rc')
+            if last_vers != version.__version__:
+                self.config.setStrValue('internal.msg_rc', version.__version__)
+                self._open_release_candidate_dialog()
+
     @property
     def showHiddenFiles(self):
         return self.config.boolValue('qt.show_hidden_files', False)
@@ -574,22 +580,24 @@ class MainWindow(QMainWindow):
             'act_restore': (
                 icon.RESTORE, _('Restore'),
                 self.restoreThis, None,
-                _('Restore the selected files or folders to the '
+                _('Restore the selected files or directories to the '
                   'original destination.')),
             'act_restore_to': (
                 icon.RESTORE_TO, _('Restore to …'),
                 self.restoreThisTo, None,
-                _('Restore the selected files or folders to a '
+                _('Restore the selected files or directories to a '
                   'new destination.')),
             'act_restore_parent': (
-                icon.RESTORE, 'RESTORE PARENT (DEBUG)',
+                icon.RESTORE,
+                None,  # text label is set elsewhere
                 self.restoreParent, None,
-                _('Restore the currently shown folder and all its contents '
+                _('Restore the currently shown directory and all its contents '
                   'to the original destination.')),
             'act_restore_parent_to': (
-                icon.RESTORE_TO, 'RESTORE PARENT TO (DEBUG)',
+                icon.RESTORE_TO,
+                None,  # text label is set elsewhere
                 self.restoreParentTo, None,
-                _('Restore the currently shown folder and all its contents '
+                _('Restore the currently shown directory and all its contents '
                   'to a new destination.')),
             'act_folder_up': (
                 icon.UP, _('Up'),
@@ -624,6 +632,16 @@ class MainWindow(QMainWindow):
             # populate the action to "self"
             setattr(self, attr, action)
 
+        # Release Candidate ?
+        self.act_help_release_candidate = None
+        if version.is_release_candidate():
+            # pylint: disable=undefined-variable
+            action = QAction(icon.QUESTION, _('Release Candidate'), self)
+            action.triggered.connect(self.slot_help_release_candidate)
+            action.setToolTip(
+                _('Shows the message about this Release Candidate again.'))
+            self.act_help_release_candidate = action
+
         # Fine tuning
         self.act_shutdown.toggled.connect(self.btnShutdownToggled)
         self.act_shutdown.setCheckable(True)
@@ -713,6 +731,9 @@ class MainWindow(QMainWindow):
         help = self.menuBar().actions()[-1].menu()
         help.insertSeparator(self.act_help_website)
         help.insertSeparator(self.act_help_about)
+        if self.act_help_release_candidate:
+            help.addSeparator()
+            help.addAction(self.act_help_release_candidate)
         restore = self.act_restore_menu.menu()
         restore.insertSeparator(self.act_restore_parent)
         restore.setToolTipsVisible(True)
@@ -823,8 +844,6 @@ class MainWindow(QMainWindow):
             if answer != QMessageBox.StandardButton.Yes:
                 return event.ignore()
 
-        self.qapp.removeEventFilter(self.mouseButtonEventFilter)
-
         self.config.setStrValue('qt.last_path', self.path)
         self.config.setProfileStrValue('qt.last_path', self.path)
 
@@ -880,13 +899,9 @@ class MainWindow(QMainWindow):
 
         self.comboProfiles.clear()
 
+        qttools.update_combo_profiles(self.config, self.comboProfiles, self.config.currentProfile())
         profiles = self.config.profilesSortedByName()
 
-        for profile_id in profiles:
-            self.comboProfiles.addProfileID(profile_id)
-            if profile_id == self.config.currentProfile():
-                self.comboProfiles.setCurrentProfileID(profile_id)
-
         self.comboProfilesAction.setVisible(len(profiles) > 1)
 
         self.updateProfile()
@@ -1176,7 +1191,7 @@ class MainWindow(QMainWindow):
             reverse = True if indic == Qt.SortOrder.DescendingOrder else False
             include_folders = sorted(include_folders, reverse=reverse)
 
-        self.addPlace(_('Backup folders'), '', '')
+        self.addPlace(_('Backup directories'), '', '')
 
         for folder in include_folders:
             self.addPlace(folder, folder, 'document-save')
@@ -1344,7 +1359,7 @@ class MainWindow(QMainWindow):
 
     def btnSettingsClicked(self):
         with self.suspendMouseButtonNavigation():
-            settingsdialog.SettingsDialog(self).show()
+            SettingsDialog(self).show()
 
     def btnShutdownToggled(self, checked):
         self.shutdown.activate_shutdown = checked
@@ -1473,26 +1488,28 @@ class MainWindow(QMainWindow):
         return {'widget': fileList, 'retFunc': None}
 
     def deleteOnRestore(self):
-        cb = QCheckBox(_('Remove newer elements in original folder.'))
+        cb = QCheckBox(_('Remove newer elements in original directory.'))
         qttools.set_wrapped_tooltip(
             cb,
-            _('Restore selected files or folders to the original destination '
-              'and delete files or folders which are not in the snapshot. Be '
-              'extremely careful because this will delete files and folders '
-              'which were excluded during taking the snapshot.')
+            _('Restore selected files or directories to the original '
+              'destination and delete files or directories which are not in '
+              'the snapshot. Be extremely careful because this will delete '
+              'files and directories which were excluded during taking the '
+              'snapshot.')
         )
         return {'widget': cb, 'retFunc': cb.isChecked, 'id': 'delete'}
 
-    def confirmRestore(self, paths, restoreTo = None):
+    def confirmRestore(self, paths, restoreTo=None):
         if restoreTo:
             msg = ngettext(
                 # singular
                 'Do you really want to restore this element into the '
-                'new folder\n{path}?',
+                'new directory?',
                 # plural
                 'Do you really want to restore these elements into the '
-                'new folder\n{path}?',
-                len(paths)).format(path=restoreTo)
+                'new directory?',
+                len(paths))
+            msg = f'{msg}\n{restoreTo}'
         else:
             msg = ngettext(
                 # singular
@@ -1501,21 +1518,25 @@ class MainWindow(QMainWindow):
                 'Do you really want to restore these elements?',
                 len(paths))
 
-        confirm, opt = messagebox.warningYesNoOptions(self,
-                                                      msg,
-                                                      (self.listRestorePaths(paths),
-                                                       self.backupOnRestore(),
-                                                       self.restoreOnlyNew(),
-                                                       self.deleteOnRestore()))
+        confirm, opt = messagebox.warningYesNoOptions(
+            self,
+            msg,
+            (
+                self.listRestorePaths(paths),
+                self.backupOnRestore(),
+                self.restoreOnlyNew(),
+                self.deleteOnRestore()
+            )
+        )
         return (confirm, opt)
 
-    def confirmDelete(self, warnRoot = False, restoreTo = None):
+    def confirmDelete(self, warnRoot=False, restoreTo=None):
         if restoreTo:
             msg = _('Are you sure you want to remove all newer files '
                     'in {path}?').format(path=restoreTo)
         else:
             msg = _('Are you sure you want to remove all newer files in your '
-                    'original folder?')
+                    'original directory?')
 
         if warnRoot:
             msg = f'<p>{msg}</p><p>'
@@ -1933,9 +1954,121 @@ class MainWindow(QMainWindow):
         if perc > cutoff:
             return
 
-        dlg = languagedialog.ApproachTranslatorDialog(self, name, perc)
+        def _complete_text(language: str, percent: int) -> str:
+            # (2023-08): Move to packages meta-data (pyproject.toml).
+            _URL_PLATFORM = 'https://translate.codeberg.org/engage/backintime'
+            _URL_PROJECT = 'https://github.com/bit-team/backintime'
+
+            txt = _(
+                'Hello'
+                '\n'
+                'You have used Back In Time in the {language} '
+                'language a few times by now.'
+                '\n'
+                'The translation of your installed version of Back In Time '
+                'into {language} is {perc} complete. Regardless of your '
+                'level of technical expertise, you can contribute to the '
+                'translation and thus Back In Time itself.'
+                '\n'
+                'Please visit the {translation_platform_url} if you wish '
+                'to contribute. For further assistance and questions, '
+                'please visit the {back_in_time_project_website}.'
+                '\n'
+                'We apologize for the interruption, and this message '
+                'will not be shown again. This dialog is available at '
+                'any time via the help menu.'
+                '\n'
+                'Your Back In Time Team'
+            )
+
+            # Wrap paragraphs in <p> tags.
+            result = ''
+            for t in txt.split('\n'):
+                result = f'{result}<p>{t}</p>'
+
+            # Insert data in placeholder variables.
+            platform_url \
+                = f'<a href="{_URL_PLATFORM}">' \
+                + _('translation platform') \
+                + '</a>'
+
+            project_url \
+                = f'<a href="{_URL_PROJECT}">Back In Time ' \
+                + _('Website') \
+                + ' </a>'
+
+            result = result.format(
+                language=f'<strong>{language}</strong>',
+                perc=f'<strong>{percent} %</strong>',
+                translation_platform_url=platform_url,
+                back_in_time_project_website=project_url
+            )
+
+            return result
+
+        dlg = UserMessageDialog(
+            parent=self,
+            title=_('Your translation'),
+            full_label=_complete_text(name, perc))
         dlg.exec()
 
+    def _open_release_candidate_dialog(self):
+        html_contact_list = (
+            '<ul>'
+            '<li>{email}</li>'
+            '<li>{mailinglist}</li>'
+            '<li>{issue}</li>'
+            '<li>{alternative}</li>'
+            '</ul>').format(
+                email=_('Email to {link_and_label}.').format(
+                    link_and_label='<a href="mailto:backintime@tuta.io">'
+                                   'backintime@tuta.io</a>'),
+                mailinglist=_('Mailing list {link_and_label}').format(
+                    link_and_label='<a href="https://mail.python.org/mailman3/'
+                                   'lists/bit-dev.python.org/">'
+                                   'bit-dev@python.org</a>'),
+                issue=_('{link_and_label} on the project website.').format(
+                    link_and_label='<a href="https://github.com/bit-team/'
+                                   'backintime/issues/new">{open_issue}</a>').format(
+                                       open_issue=_('Open an issue')),
+                alternative=_('Alternatively, you can use another channel '
+                              'of your choice.')
+            )
+
+        rc_message = _(
+            'This version of Back In Time is a Release Candidate and is '
+            'primarily intended for stability testing in preparation for the '
+            'next official release.'
+            '\n'
+            'No user data or telemetry is collected. However, the Back In '
+            'Time team is very interested in knowing if the Release Candidate '
+            'is being used and if it is worth continuing to provide such '
+            'pre-release versions.'
+            '\n'
+            'Therefore, the team kindly asks for a short feedback on whether '
+            'you have tested this version, even if you didn’t encounter any '
+            'issues. Even a quick test run of a few minutes would help us a '
+            'lot.'
+            '\n'
+            'The following contact options are available:'
+            '\n'
+            '{contact_list}'
+            '\n'
+            "In this version, this message won't be shown again but can be "
+            'accessed anytime through the help menu.'
+            '\n'
+            'Thank you for your support and for helping us improve '
+            'Back In Time!'
+            '\n'
+            'Your Back In Time Team').format(contact_list=html_contact_list)
+
+        dlg = UserMessageDialog(
+            parent=self,
+            title=_('Release Candidate'),
+            full_label=rc_message)
+        dlg.exec()
+
+
     # |-------|
     # | Slots |
     # |-------|
@@ -1961,6 +2094,9 @@ class MainWindow(QMainWindow):
     def slot_help_translation(self):
         self._open_approach_translator_dialog()
 
+    def slot_help_release_candidate(self):
+        self._open_release_candidate_dialog()
+
     def slot_help_encryption(self):
         dlg = encfsmsgbox.EncfsExistsWarning(self, ['(not determined)'])
         dlg.exec()
@@ -2028,11 +2164,13 @@ class RemoveSnapshotThread(QThread):
         if self.config.inhibitCookie:
             self.config.inhibitCookie = tools.unInhibitSuspend(*self.config.inhibitCookie)
 
+
 class FillTimeLineThread(QThread):
     """
     add snapshot IDs to timeline in background
     """
     addSnapshot = pyqtSignal(snapshots.SID)
+
     def __init__(self, parent):
         self.parent = parent
         self.config = parent.config
@@ -2045,10 +2183,12 @@ class FillTimeLineThread(QThread):
 
         self.parent.snapshotsList.sort()
 
+
 class SetupCron(QThread):
     """
     Check crontab entries on startup.
     """
+
     def __init__(self, parent):
         self.config = parent.config
         super(SetupCron, self).__init__(parent)
@@ -2062,10 +2202,11 @@ if __name__ == '__main__':
 
     raiseCmd = ''
     if len(sys.argv) > 1:
-        raiseCmd = '\n'.join(sys.argv[1 :])
+        raiseCmd = '\n'.join(sys.argv[1:])
 
-    appInstance = guiapplicationinstance.GUIApplicationInstance(cfg.appInstanceFile(), raiseCmd)
-    cfg.PLUGIN_MANAGER.load(cfg = cfg)
+    appInstance = guiapplicationinstance.GUIApplicationInstance(
+        cfg.appInstanceFile(), raiseCmd)
+    cfg.PLUGIN_MANAGER.load(cfg=cfg)
     cfg.PLUGIN_MANAGER.appStart()
 
     logger.openlog()
@@ -2080,6 +2221,8 @@ if __name__ == '__main__':
         mainWindow.show()
         qapp.exec()
 
+    mainWindow.qapp.removeEventFilter(mainWindow.mouseButtonEventFilter)
+
     cfg.PLUGIN_MANAGER.appExit()
     appInstance.exitApplication()
 
