@@ -1,16 +1,20 @@
 #!/usr/bin/env python3
+# SPDX-FileCopyrightText: © 2023 Christian BUHTZ <c.buhtz@posteo.jp>
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+#
+# This file is part of the program "Back In time" which is released under GNU
+# General Public License v2 (GPLv2). See file/folder LICENSE or go to
+# <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 """This helper script does manage transferring translations to and from the
 translation platform (currently Weblate).
 """
 import sys
-import io
 import datetime
-import json
 import re
 import tempfile
 import string
 import shutil
-import pprint
 from pathlib import Path
 from subprocess import run, check_output
 from common import languages
@@ -35,6 +39,35 @@ BUG_ADDRESS = 'https://github.com/bit-team/backintime'
 REX_SHORTCUT_LETTER = re.compile(r'&(\w)')
 
 
+def dict_as_code(a_dict: dict, indent_level: int) -> list[str]:
+    """Convert a (nested) Python dict into its PEP8 conform as-in-code
+    representation.
+    """
+    tab = ' ' * 4 * indent_level
+    result = []
+    for key in a_dict:
+
+        # single quotes?
+        quote_key = "'" if isinstance(key, str) else ""
+        quote_val  = "'" if isinstance(a_dict[key], str) else ""
+
+        # A nested dict
+        if isinstance(a_dict[key], dict):
+            result.append(f"{tab}{quote_key}{key}{quote_key}: {{")
+
+            result.extend(
+                dict_as_code(a_dict[key], indent_level+1))
+
+            result.append(f"{tab}}},")
+            continue
+
+        # Regular key: value pair
+        result.append(f"{tab}{quote_key}{key}{quote_key}: "
+                      f"{quote_val}{a_dict[key]}{quote_val},")
+
+    return result
+
+
 def update_po_template():
     """The po template file is update via `xgettext`.
 
@@ -216,11 +249,11 @@ def check_syntax_of_po_files():
         # string. BIT won't use constructs like this in strings, so it is
         # handled as an error.
         if rex_curly_pair.findall(invalid):
-            print(f'\nERROR: Curly brackets nested: {to_check}')
+            print(f'\nERROR ({lang_code}): Curly brackets nested: {to_check}')
             return False
 
         if invalid:
-            print(f'\nERROR: Curly brackets not balanced : {to_check}')
+            print(f'\nERROR ({lang_code}): Curly brackets not balanced : {to_check}')
             return False
 
         return True
@@ -234,52 +267,66 @@ def check_syntax_of_po_files():
             list(string.Formatter().parse(format_string=to_check))
 
         except Exception as exc:  # pylint: disable=broad-exception-caught
-            print(f'\nERROR: {exc} in translation: {to_check}')
+            print(f'\nERROR ({lang_code}): {exc} in translation: {to_check}')
             return False
 
         return True
 
-    def _place_holders(trans_string, src_string, flags):
+    def _place_holders(trans_string, src_string, tcomments):
         """Check if the placeholders between original source string
         and the translated string are identical. Order is ignored.
 
         To disable this check for a specific string add the translation
-        flag "ignore-placeholder-compare" to the entry in the po-file.
+        comment(!) on top of the entry in the po file like this:
+
+            # ignore-placeholder-compare
+            #: qt/app.py:1961
+            #, python-brace-format
+            msgid "foo"
+            msgstr "bar"
+
+        Keep in mind that this is a regular comment. It is not a flag (``#, ``)
+        or a user defined flag (``#. ``). The later two are removed by msgmerge
+        when updating the po files from the pot file.
         """
 
-        if 'ignore-placeholder-compare' in flags:
+        if 'ignore-placeholder-compare' in tcomments:
             return True
 
-        flagmsg = 'Disable this check with flagging it with ' \
-                  '"ignore-placeholder-compare" in its po-file.'
+        flagmsg = 'To disable this check add the comment (not flag!) on ' \
+                  'top of the entry in the po-file: ' \
+                  '"# ignore-placeholder-compare"'
 
         # Compare number of curly brackets.
         for bracket in tuple('{}'):
             if src_string.count(bracket) != trans_string.count(bracket):
-                print(f'\nERROR: Number of "{bracket}" between original '
-                      'source and translated string is different.\n'
-                      f'Translation: {trans_string}\n{flagmsg}')
+                print(f'\nERROR ({lang_code}): Number of "{bracket}" between '
+                      'original source and translated string is different.\n'
+                      f'\nTranslation: {trans_string}\n\n{flagmsg}')
                 return False
 
         # Compare variable names
         org_names = rex_names.findall(src_string)
         trans_names = rex_names.findall(trans_string)
         if sorted(org_names) != sorted(trans_names):
-            print('\nERROR: Names of placeholders between original source '
-                  'and translated string are different.\n'
-                  f'Names in original    : {org_names}\n'
-                  f'Names in translation : {trans_names}\n'
-                  f'Full translation: {trans_string}\n{flagmsg}')
+            print(f'\nERROR ({lang_code}): Names of placeholders between '
+                  'original source and translated string are different.\n'
+                  f'\nNames in original    : {org_names}\n'
+                  f'\nNames in translation : {trans_names}\n'
+                  f'\nFull translation: {trans_string}\n{flagmsg}')
             return False
 
         return True
 
-    print('Checking syntax of po files...')
+    print('Checking syntax of po files…')
 
     # Each po file
     for po_path in all_po_files_in_local_dir():
+        error_count = 0
         # Language code determined by po-filename
-        print(f'{po_path.with_suffix("").name}', end=' ')
+        lang_code = po_path.with_suffix('').name
+
+        # print(f'{lang_code}', end=' ')
 
         pof = polib.pofile(po_path)
 
@@ -295,8 +342,14 @@ def check_syntax_of_po_files():
                     or not _other_errors(entry.msgstr)
                     or not _place_holders(entry.msgstr,
                                           entry.msgid,
-                                          entry.flags)):
-                print(f'Source string: {entry.msgid}\n')
+                                          entry.tcomment)):
+                print(f'\nSource string: {entry.msgid}\n')
+                error_count += 1
+
+        if error_count:
+            print(f' {lang_code} >> {error_count} errors')
+        else:
+            print(f' {lang_code} >> OK')
 
     print('')
 
@@ -311,7 +364,7 @@ def create_completeness_dict():
     indicate the completeness of the translation in percent.
     """
 
-    print('Calculate completeness for each language in percent...')
+    print('Calculate completeness for each language in percent…')
 
     result = {}
 
@@ -342,36 +395,33 @@ def create_languages_file():
     """
 
     # Convert language names dict to python code as a string
-    names = update_language_names()
-    stream = io.StringIO()
-    pprint.pprint(names, indent=2, stream=stream, sort_dicts=True)
-    stream.seek(0)
-    names = stream.read()
+    names_dict = update_language_names()
+    content = ['names = {']
+    content.extend(dict_as_code(names_dict, 1))
+    content.append('}')
 
     # the same with completeness dict
     compl_dict = create_completeness_dict()
-    stream = io.StringIO()
-    pprint.pprint(compl_dict, indent=2, stream=stream, sort_dicts=True)
-    stream.seek(0)
-    completeness = stream.read()
+    content.append('')
+    content.append('')
+    content.append('completeness = {')
+    content.extend(dict_as_code(compl_dict, 1))
+    content.append('}')
 
     with LANGUAGE_NAMES_PY.open('w', encoding='utf8') as handle:
 
         date_now = datetime.datetime.now().strftime('%c')
         handle.write(
-            f'# Generated at {date_now} with help of package "babel" '
+            f'# Generated at {date_now} with help\n# of package "babel" '
             'and "polib".\n')
         handle.write('# https://babel.pocoo.org\n')
         handle.write('# https://github.com/python-babel/babel\n')
+        handle.write(
+            '# pylint: disable=too-many-lines,missing-module-docstring\n')
 
-        handle.write('\nnames = {\n')
-        handle.write(names[1:])
-
+        handle.write('\n'.join(content))
         handle.write('\n')
 
-        handle.write('\ncompleteness = {\n')
-        handle.write(completeness[1:])
-
     print(f'Result written to {LANGUAGE_NAMES_PY}.')
 
     # Completeness statistics (English is excluded)
@@ -411,6 +461,13 @@ def create_language_names_dict(language_codes: list) -> dict:
         raise ImportError(
             'Can not import package "babel". Please install it.') from exc
 
+    # Babel minimum version (because language code "ie")
+    from packaging.version import Version
+    if Version(babel.__version__) < Version('2.15'):
+        raise ImportError(
+            f'Babel version 2.15 required. But {babel.__version__} '
+            'is installed.')
+
     # Source language (English) should be included
     if 'en' not in language_codes:
         language_codes.append('en')
@@ -418,8 +475,8 @@ def create_language_names_dict(language_codes: list) -> dict:
     # Don't use defaultdict because pprint can't handle it
     result = {}
 
-    for code in language_codes:
-        print(f'Processing language code "{code}"...')
+    for code in sorted(language_codes):
+        print(f'Processing language code "{code}"…')
 
         lang = babel.Locale.parse(code)
         result[code] = {}
